================
Docstring styles
================

The default output format also comes with four different docstring styles to choose.

.. tab:: reStructuredText

    .. literalinclude:: /../tests/fixtures/docstrings/rst/schema.py
       :language: python
       :lines: 37-

.. tab:: NumPy

    .. literalinclude:: /../tests/fixtures/docstrings/numpy/schema.py
       :language: python
       :lines: 39-

.. tab:: Google

    .. literalinclude:: /../tests/fixtures/docstrings/google/schema.py
       :language: python
       :lines: 38-

.. tab:: Accessible

    This custom xsdata style offers easy access to the docstrings during runtime.

    .. literalinclude:: /../tests/fixtures/docstrings/accessible/schema.py
       :language: python
       :lines: 39-

.. tab:: Blank

    Disable docstrings generation.

    .. literalinclude:: /../tests/fixtures/docstrings/accessible/schema.py
       :language: python
       :lines: 25-
